@@ -145,13 +145,14 @@ if(plot_type==2):
                 Zq = np.genfromtxt(prefix+'Zqs'+appendix,skip_header=to_skip+1, max_rows=meta)
                 for n in range(tot_atoms_uc*3):
                     params = Params[:,n]
-                    if(gaussian_smoothing != 0):
-                        if(gaussian_smoothing < 0):
-                            sig, mi = params[-1]/2.355, freq[int(len(freq)/2)]
-                        else:
-                            sig, mi = gaussian_smoothing, freq[int(len(freq)/2)]
-                    if(sig==0):
-                        sig = freq[1]-freq[0]
+                    if(gaussian_smoothing > 0):
+                        sig, mi = gaussian_smoothing, freq[int(len(freq)/2)]
+                    elif(gaussian_smoothing == 0 or gaussian_smoothing == 0.0):
+                        sig, mi = freq[1]-freq[0], freq[int(len(freq)/2)]
+                    else:
+                        sig, mi = params[-1]/2.355, freq[int(len(freq)/2)]
+                        if(sig==0 or sig==0.0):
+                            sig = freq[1]-freq[0]
                     
                     gaussian = util.norm_gaussian(freq, mi, sig)                
                     # convolution_lorentzian = signal.fftconvolve(Z[:,n], plot.lorentzian(freq, freq[int(len(freq)/2)], params[1], params[2]), mode='same') / sum( plot.lorentzian(freq, *params))
